@@ -28,7 +28,39 @@ class RequestProxy(object):
         if port is None:
             raise SDKException(Constants.USER_PROXY_ERROR, Constants.PORT_ERROR_MESSAGE)
 
-        self.host = host
-        self.port = port
-        self.user = user
-        self.password = "" if password is None else password
+        self.__host = host
+        self.__port = port
+        self.__user = user
+        self.__password = "" if password is None else password
+
+    def get_host(self):
+        """
+        This is a getter method to get __host.
+
+        Returns:
+            string: A string representing __host
+        """
+
+    def get_port(self):
+        """
+        This is a getter method to get __port.
+
+        Returns:
+            string: A string representing __port
+        """
+
+    def get_user(self):
+        """
+        This is a getter method to get __user.
+
+        Returns:
+            string: A string representing __user
+        """
+
+    def get_password(self):
+        """
+        This is a getter method to get __password.
+
+        Returns:
+            string: A string representing __password
+        """
\ No newline at end of file
