@@ -27,7 +27,7 @@ class Downloader(Converter):
         self.unique_dict = {}
         self.common_api_handler = common_api_handler
 
-    def form_request(self, request_object, pack, instance_number, class_member_detail):
+    def form_request(self, request_instance, pack, instance_number, class_member_detail):
 
         return None
 
@@ -85,15 +85,18 @@ class Downloader(Converter):
 
             return instance
 
-    def construct_private_member(self, class_name, member_name):
+    @staticmethod
+    def construct_private_member(class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    def get_class(self, class_name, class_path):
+    @staticmethod
+    def get_class(class_name, class_path):
         imported_module = importlib.import_module(class_path)
         class_holder = getattr(imported_module, class_name)
         return class_holder
 
-    def module_to_class(self, module_name):
+    @staticmethod
+    def module_to_class(module_name):
         class_name = module_name
 
         if "_" in module_name:
