@@ -3,7 +3,7 @@ try:
     import logging
     import re
     import json
-    from zcrmsdk.src.com.zoho.crm.api.util import Converter, Constants, StreamWrapper
+    from zcrmsdk.src.com.zoho.crm.api.util import Utility,Converter, Constants, StreamWrapper
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
 
 except Exception:
@@ -12,6 +12,7 @@ except Exception:
     import re
     from .converter import Converter
     from .constants import Constants
+    from .utility import Utility
     from .stream_wrapper import StreamWrapper
     from ..exception import SDKException
 
@@ -30,6 +31,7 @@ class FormDataConverter(Converter):
         self.common_api_handler = common_api_handler
 
     def form_request(self, request_instance, pack, instance_number, class_member_detail):
+
         path_split = str(pack).rpartition(".")
         class_name = self.module_to_class(path_split[-1])
         pack = path_split[0] + "." + class_name
@@ -167,17 +169,17 @@ class FormDataConverter(Converter):
             return request
 
     def get_wrapped_response(self, response, pack):
-
         return None
 
     def get_response(self, response, pack):
-
         return None
 
-    def construct_private_member(self, class_name, member_name):
+    @staticmethod
+    def construct_private_member(class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    def module_to_class(self, module_name):
+    @staticmethod
+    def module_to_class(module_name):
         class_name = module_name
 
         if "_" in module_name:
